@@ -45,7 +45,7 @@ class FolderCreationOrUpdateHook(Hook):
     def __call__(self):
         session = self._cw
         entity = self.entity
-        if 'name' not in entity: # was not edited
+        if 'name' not in entity.cw_edited: # was not edited
             return
         try:
             parent = entity.filed_under[0]
